@@ -1,15 +1,6 @@
-/* lmder.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
 #include "cminpack.h"
 #include <math.h>
-#define real __cminpack_real__
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-#define max(a,b) ((a) >= (b) ? (a) : (b))
-#define TRUE_ (1)
-#define FALSE_ (0)
+#include "cminpackP.h"
 
 __cminpack_attr__
 int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n, real *x, 
@@ -21,9 +12,9 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
 {
     /* Initialized data */
 
-#define p1 .1
-#define p5 .5
-#define p25 .25
+#define p1 ((real).1)
+#define p5 ((real).5)
+#define p25 ((real).25)
 #define p75 .75
 #define p0001 1e-4
 
@@ -251,7 +242,7 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
     if (iflag < 0) {
 	goto TERMINATE;
     }
-    fnorm = __cminpack_func__(enorm)(m, fvec);
+    fnorm = __cminpack_enorm__(m, fvec);
 
 /*     initialize levenberg-marquardt parameter and iteration counter. */
 
@@ -306,7 +297,7 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
             for (j = 0; j < n; ++j) {
                 wa3[j] = diag[j] * x[j];
             }
-            xnorm = __cminpack_func__(enorm)(n, wa3);
+            xnorm = __cminpack_enorm__(n, wa3);
             delta = factor * xnorm;
             if (delta == 0.) {
                 delta = factor;
@@ -387,7 +378,7 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
                 wa2[j] = x[j] + wa1[j];
                 wa3[j] = diag[j] * wa1[j];
             }
-            pnorm = __cminpack_func__(enorm)(n, wa3);
+            pnorm = __cminpack_enorm__(n, wa3);
 
 /*           on the first iteration, adjust the initial step bound. */
 
@@ -402,7 +393,7 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
             if (iflag < 0) {
                 goto TERMINATE;
             }
-            fnorm1 = __cminpack_func__(enorm)(m, wa4);
+            fnorm1 = __cminpack_enorm__(m, wa4);
 
 /*           compute the scaled actual reduction. */
 
@@ -410,7 +401,7 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
             if (p1 * fnorm1 < fnorm) {
                 /* Computing 2nd power */
                 d1 = fnorm1 / fnorm;
-                actred = 1. - d1 * d1;
+                actred = 1 - d1 * d1;
             }
 
 /*           compute the scaled predicted reduction and */
@@ -424,7 +415,7 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
                     wa3[i] += fjac[i + j * ldfjac] * temp;
                 }
             }
-            temp1 = __cminpack_func__(enorm)(n, wa3) / fnorm;
+            temp1 = __cminpack_enorm__(n, wa3) / fnorm;
             temp2 = (sqrt(par) * pnorm) / fnorm;
             prered = temp1 * temp1 + temp2 * temp2 / p5;
             dirder = -(temp1 * temp1 + temp2 * temp2);
@@ -472,7 +463,7 @@ int __cminpack_func__(lmder)(__cminpack_decl_fcnder_mn__ void *p, int m, int n,
                 for (i = 0; i < m; ++i) {
                     fvec[i] = wa4[i];
                 }
-                xnorm = __cminpack_func__(enorm)(n, wa2);
+                xnorm = __cminpack_enorm__(n, wa2);
                 fnorm = fnorm1;
                 ++iter;
             }
